package com.doc.biz.controller;

import com.doc.biz.domain.DocDir;
import com.doc.biz.service.IDocDirService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文档目录管理Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档目录管理")
@RestController
@RequestMapping("/biz/dir")
public class DocDirController extends BaseController {
    @Resource
    private IDocDirService docDirService;

    /**
     * 查询文档目录管理列表
     */
    @ApiOperation("查询文档目录管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:dir:list')")
    @GetMapping("/list")
    public AjaxResult list(DocDir docDir) {
        List<DocDir> list = docDirService.selectDocDirList(docDir);
        return success(list);
    }

    /**
     * 导出文档目录管理列表
     */
    @ApiOperation("导出文档目录管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:dir:export')")
    @Log(title = "文档目录管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocDir docDir) {
        List<DocDir> list = docDirService.selectDocDirList(docDir);
        ExcelUtil<DocDir> util = new ExcelUtil<DocDir>(DocDir.class);
        util.exportExcel(response, list, "文档目录管理数据");
    }

    /**
     * 获取文档目录管理详细信息
     */
    @ApiOperation("获取文档目录管理详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:dir:query')")
    @GetMapping(value = "/{dirId}")
    public AjaxResult getInfo(@PathVariable("dirId") Long dirId) {
        return success(docDirService.selectDocDirByDirId(dirId));
    }

    /**
     * 新增文档目录管理
     */
    @ApiOperation("新增文档目录管理")
    //@PreAuthorize("@ss.hasPermi('biz:dir:add')")
    @Log(title = "文档目录管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocDir docDir) {
        return toAjax(docDirService.insertDocDir(docDir));
    }

    /**
     * 修改文档目录管理
     */
    @ApiOperation("修改文档目录管理")
    //@PreAuthorize("@ss.hasPermi('biz:dir:edit')")
    @Log(title = "文档目录管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocDir docDir) {
        return toAjax(docDirService.updateDocDir(docDir));
    }

    /**
     * 删除文档目录管理
     */
    @ApiOperation("删除文档目录管理")
    //@PreAuthorize("@ss.hasPermi('biz:dir:remove')")
    @Log(title = "文档目录管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{dirIds}")
    public AjaxResult remove(@PathVariable Long[] dirIds) {
        return toAjax(docDirService.deleteDocDirByDirIds(dirIds));
    }
}
