package com.doc.biz.controller;

import com.doc.biz.domain.DocSpace;
import com.doc.biz.service.IDocSpaceService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.enums.SpaceType;
import com.doc.common.utils.SecurityUtils;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.security.Security;
import java.util.List;

/**
 * 文档空间管理Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档空间管理")
@RestController
@RequestMapping("/biz/space")
public class DocSpaceController extends BaseController {
    @Resource
    private IDocSpaceService docSpaceService;

    /**
     * 查询文档空间管理列表
     */
    @ApiOperation("查询文档空间管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:space:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocSpace docSpace) {
        startPage();
        List<DocSpace> list = docSpaceService.selectDocSpaceList(docSpace);
        return getDataTable(list);
    }

    /**
     * 导出文档空间管理列表
     */
    @ApiOperation("导出文档空间管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:space:export')")
    @Log(title = "文档空间管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocSpace docSpace) {
        List<DocSpace> list = docSpaceService.selectDocSpaceList(docSpace);
        ExcelUtil<DocSpace> util = new ExcelUtil<DocSpace>(DocSpace.class);
        util.exportExcel(response, list, "文档空间管理数据");
    }

    /**
     * 获取文档空间管理详细信息
     */
    @ApiOperation("获取文档空间管理详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:space:query')")
    @GetMapping(value = "/{spaceId}")
    public AjaxResult getInfo(@PathVariable("spaceId") Long spaceId) {
        return success(docSpaceService.selectDocSpaceBySpaceId(spaceId));
    }

    /**
     * 获取空间详情
     */
    @ApiOperation("获取空间信息")
    @GetMapping(value = "/{spaceType}")
    public AjaxResult getInfo(@ApiParam(value = "空间类型（1.公共 2.部门 3.个人）", required = true) @PathVariable("spaceType") String spaceType) {
        DocSpace search = new DocSpace();
        search.setSpaceType(spaceType);
        switch (spaceType) {
//            case "1":
//                break;
            case "2":
                search.setOwner(SecurityUtils.getDeptId());
                break;
            case "3":
                search.setOwner(SecurityUtils.getUserId());
                break;
            default:
        }

        List<DocSpace> list = docSpaceService.selectDocSpaceList(search);
        return success(list.get(0));
    }

    /**
     * 新增文档空间管理
     */
    @ApiOperation("新增文档空间管理")
    //@PreAuthorize("@ss.hasPermi('biz:space:add')")
    @Log(title = "文档空间管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocSpace docSpace) {
        return toAjax(docSpaceService.insertDocSpace(docSpace));
    }

    /**
     * 修改文档空间管理
     */
    @ApiOperation("修改文档空间管理")
    //@PreAuthorize("@ss.hasPermi('biz:space:edit')")
    @Log(title = "文档空间管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocSpace docSpace) {
        return toAjax(docSpaceService.updateDocSpace(docSpace));
    }

    /**
     * 删除文档空间管理
     */
    @ApiOperation("删除文档空间管理")
    //@PreAuthorize("@ss.hasPermi('biz:space:remove')")
    @Log(title = "文档空间管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{spaceIds}")
    public AjaxResult remove(@PathVariable Long[] spaceIds) {
        return toAjax(docSpaceService.deleteDocSpaceBySpaceIds(spaceIds));
    }
}
