package com.doc.biz.service.impl;

import com.doc.biz.domain.DocActor;
import com.doc.biz.mapper.DocActorMapper;
import com.doc.biz.service.IDocActorService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档协作Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocActorServiceImpl implements IDocActorService {
    @Resource
    private DocActorMapper docActorMapper;

    /**
     * 查询文档协作
     *
     * @param autoId 文档协作主键
     * @return 文档协作
     */
    @Override
    public DocActor selectDocActorByAutoId(Long autoId) {
        return docActorMapper.selectDocActorByAutoId(autoId);
    }

    /**
     * 查询文档协作列表
     *
     * @param docActor 文档协作
     * @return 文档协作
     */
    @Override
    public List<DocActor> selectDocActorList(DocActor docActor) {
        return docActorMapper.selectDocActorList(docActor);
    }

    /**
     * 新增文档协作
     *
     * @param docActor 文档协作
     * @return 结果
     */
    @Override
    public int insertDocActor(DocActor docActor) {
        docActor.setCreateTime(DateUtils.getNowDate());
        return docActorMapper.insertDocActor(docActor);
    }

    /**
     * 修改文档协作
     *
     * @param docActor 文档协作
     * @return 结果
     */
    @Override
    public int updateDocActor(DocActor docActor) {
        docActor.setUpdateTime(DateUtils.getNowDate());
        return docActorMapper.updateDocActor(docActor);
    }

    /**
     * 批量删除文档协作
     *
     * @param autoIds 需要删除的文档协作主键
     * @return 结果
     */
    @Override
    public int deleteDocActorByAutoIds(Long[] autoIds) {
        return docActorMapper.deleteDocActorByAutoIds(autoIds);
    }

    /**
     * 删除文档协作信息
     *
     * @param autoId 文档协作主键
     * @return 结果
     */
    @Override
    public int deleteDocActorByAutoId(Long autoId) {
        return docActorMapper.deleteDocActorByAutoId(autoId);
    }
}
