package com.doc.biz.service.impl;

import com.doc.biz.domain.DocDir;
import com.doc.biz.mapper.DocDirMapper;
import com.doc.biz.service.IDocDirService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档目录管理Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocDirServiceImpl implements IDocDirService {
    @Resource
    private DocDirMapper docDirMapper;

    /**
     * 查询文档目录管理
     *
     * @param dirId 文档目录管理主键
     * @return 文档目录管理
     */
    @Override
    public DocDir selectDocDirByDirId(Long dirId) {
        return docDirMapper.selectDocDirByDirId(dirId);
    }

    /**
     * 查询文档目录管理列表
     *
     * @param docDir 文档目录管理
     * @return 文档目录管理
     */
    @Override
    public List<DocDir> selectDocDirList(DocDir docDir) {
        return docDirMapper.selectDocDirList(docDir);
    }

    /**
     * 新增文档目录管理
     *
     * @param docDir 文档目录管理
     * @return 结果
     */
    @Override
    public int insertDocDir(DocDir docDir) {
        docDir.setCreateTime(DateUtils.getNowDate());
        return docDirMapper.insertDocDir(docDir);
    }

    /**
     * 修改文档目录管理
     *
     * @param docDir 文档目录管理
     * @return 结果
     */
    @Override
    public int updateDocDir(DocDir docDir) {
        docDir.setUpdateTime(DateUtils.getNowDate());
        return docDirMapper.updateDocDir(docDir);
    }

    /**
     * 批量删除文档目录管理
     *
     * @param dirIds 需要删除的文档目录管理主键
     * @return 结果
     */
    @Override
    public int deleteDocDirByDirIds(Long[] dirIds) {
        return docDirMapper.deleteDocDirByDirIds(dirIds);
    }

    /**
     * 删除文档目录管理信息
     *
     * @param dirId 文档目录管理主键
     * @return 结果
     */
    @Override
    public int deleteDocDirByDirId(Long dirId) {
        return docDirMapper.deleteDocDirByDirId(dirId);
    }
}
