package com.doc.biz.service.impl;

import com.doc.biz.domain.DocShare;
import com.doc.biz.mapper.DocShareMapper;
import com.doc.biz.service.IDocShareService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档分享Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocShareServiceImpl implements IDocShareService {
    @Resource
    private DocShareMapper docShareMapper;

    /**
     * 查询文档分享
     *
     * @param shareId 文档分享主键
     * @return 文档分享
     */
    @Override
    public DocShare selectDocShareByShareId(Long shareId) {
        return docShareMapper.selectDocShareByShareId(shareId);
    }

    /**
     * 查询文档分享列表
     *
     * @param docShare 文档分享
     * @return 文档分享
     */
    @Override
    public List<DocShare> selectDocShareList(DocShare docShare) {
        return docShareMapper.selectDocShareList(docShare);
    }

    /**
     * 新增文档分享
     *
     * @param docShare 文档分享
     * @return 结果
     */
    @Override
    public int insertDocShare(DocShare docShare) {
        docShare.setCreateTime(DateUtils.getNowDate());
        return docShareMapper.insertDocShare(docShare);
    }

    /**
     * 修改文档分享
     *
     * @param docShare 文档分享
     * @return 结果
     */
    @Override
    public int updateDocShare(DocShare docShare) {
        docShare.setUpdateTime(DateUtils.getNowDate());
        return docShareMapper.updateDocShare(docShare);
    }

    /**
     * 批量删除文档分享
     *
     * @param shareIds 需要删除的文档分享主键
     * @return 结果
     */
    @Override
    public int deleteDocShareByShareIds(Long[] shareIds) {
        return docShareMapper.deleteDocShareByShareIds(shareIds);
    }

    /**
     * 删除文档分享信息
     *
     * @param shareId 文档分享主键
     * @return 结果
     */
    @Override
    public int deleteDocShareByShareId(Long shareId) {
        return docShareMapper.deleteDocShareByShareId(shareId);
    }
}
