package com.doc.biz.service.impl;

import com.doc.biz.domain.DocSpaceExpansion;
import com.doc.biz.mapper.DocSpaceExpansionMapper;
import com.doc.biz.service.IDocSpaceExpansionService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 空间扩容管理Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocSpaceExpansionServiceImpl implements IDocSpaceExpansionService {
    @Resource
    private DocSpaceExpansionMapper docSpaceExpansionMapper;

    /**
     * 查询空间扩容管理
     *
     * @param autoId 空间扩容管理主键
     * @return 空间扩容管理
     */
    @Override
    public DocSpaceExpansion selectDocSpaceExpansionByAutoId(Long autoId) {
        return docSpaceExpansionMapper.selectDocSpaceExpansionByAutoId(autoId);
    }

    /**
     * 查询空间扩容管理列表
     *
     * @param docSpaceExpansion 空间扩容管理
     * @return 空间扩容管理
     */
    @Override
    public List<DocSpaceExpansion> selectDocSpaceExpansionList(DocSpaceExpansion docSpaceExpansion) {
        return docSpaceExpansionMapper.selectDocSpaceExpansionList(docSpaceExpansion);
    }

    /**
     * 新增空间扩容管理
     *
     * @param docSpaceExpansion 空间扩容管理
     * @return 结果
     */
    @Override
    public int insertDocSpaceExpansion(DocSpaceExpansion docSpaceExpansion) {
        docSpaceExpansion.setCreateTime(DateUtils.getNowDate());
        return docSpaceExpansionMapper.insertDocSpaceExpansion(docSpaceExpansion);
    }

    /**
     * 修改空间扩容管理
     *
     * @param docSpaceExpansion 空间扩容管理
     * @return 结果
     */
    @Override
    public int updateDocSpaceExpansion(DocSpaceExpansion docSpaceExpansion) {
        docSpaceExpansion.setUpdateTime(DateUtils.getNowDate());
        return docSpaceExpansionMapper.updateDocSpaceExpansion(docSpaceExpansion);
    }

    /**
     * 批量删除空间扩容管理
     *
     * @param autoIds 需要删除的空间扩容管理主键
     * @return 结果
     */
    @Override
    public int deleteDocSpaceExpansionByAutoIds(Long[] autoIds) {
        return docSpaceExpansionMapper.deleteDocSpaceExpansionByAutoIds(autoIds);
    }

    /**
     * 删除空间扩容管理信息
     *
     * @param autoId 空间扩容管理主键
     * @return 结果
     */
    @Override
    public int deleteDocSpaceExpansionByAutoId(Long autoId) {
        return docSpaceExpansionMapper.deleteDocSpaceExpansionByAutoId(autoId);
    }
}
