package com.doc.biz.service.impl;

import com.doc.biz.domain.DocVersion;
import com.doc.biz.mapper.DocVersionMapper;
import com.doc.biz.service.IDocVersionService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档版本信息Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocVersionServiceImpl implements IDocVersionService {
    @Resource
    private DocVersionMapper docVersionMapper;

    /**
     * 查询文档版本信息
     *
     * @param versionId 文档版本信息主键
     * @return 文档版本信息
     */
    @Override
    public DocVersion selectDocVersionByVersionId(Long versionId) {
        return docVersionMapper.selectDocVersionByVersionId(versionId);
    }

    /**
     * 查询文档版本信息列表
     *
     * @param docVersion 文档版本信息
     * @return 文档版本信息
     */
    @Override
    public List<DocVersion> selectDocVersionList(DocVersion docVersion) {
        return docVersionMapper.selectDocVersionList(docVersion);
    }

    /**
     * 新增文档版本信息
     *
     * @param docVersion 文档版本信息
     * @return 结果
     */
    @Override
    public int insertDocVersion(DocVersion docVersion) {
        docVersion.setCreateTime(DateUtils.getNowDate());
        return docVersionMapper.insertDocVersion(docVersion);
    }

    /**
     * 修改文档版本信息
     *
     * @param docVersion 文档版本信息
     * @return 结果
     */
    @Override
    public int updateDocVersion(DocVersion docVersion) {
        docVersion.setUpdateTime(DateUtils.getNowDate());
        return docVersionMapper.updateDocVersion(docVersion);
    }

    /**
     * 批量删除文档版本信息
     *
     * @param versionIds 需要删除的文档版本信息主键
     * @return 结果
     */
    @Override
    public int deleteDocVersionByVersionIds(Long[] versionIds) {
        return docVersionMapper.deleteDocVersionByVersionIds(versionIds);
    }

    /**
     * 删除文档版本信息信息
     *
     * @param versionId 文档版本信息主键
     * @return 结果
     */
    @Override
    public int deleteDocVersionByVersionId(Long versionId) {
        return docVersionMapper.deleteDocVersionByVersionId(versionId);
    }
}
