package com.doc.chat.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.doc.biz.domain.DocInfo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.doc.common.annotation.Excel;
import com.doc.common.core.domain.BaseEntity;

import java.util.List;

/**
 * 聊天消息管理对象 chat_msg
 *
 * @author wukai
 * @date 2023-08-25
 */
@ApiModel(value = "ChatMsg" , description = "聊天消息管理")
public class ChatMsg extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 消息ID
     */
    @ApiModelProperty("消息ID")
    @TableId
    private Long msgId;

    /**
     * 发送方用户ID
     */
    @ApiModelProperty("发送方用户ID")
    @Excel(name = "发送方用户ID")
    private Long fromId;
    /**
     * 发送方用户姓名
     */
    @ApiModelProperty("发送方用户姓名")
    @Excel(name = "发送方用户姓名")
    @TableField(exist = false)
    private String fromName;
    /**
     * 发送方用户头像
     */
    @ApiModelProperty("发送方用户头像")
    @TableField(exist = false)
    private String fromAvatar;
    /**
     * 接受方用户ID
     */
    @ApiModelProperty("接收方用户ID")
    @Excel(name = "接收方用户ID")
    private Long toId;
    /**
     * 接收方用户姓名
     */
    @ApiModelProperty("接收方用户姓名")
    @TableField(exist = false)
    private String toName;
    /**
     * 接收方用户头像
     */
    @ApiModelProperty("接收方用户头像")
    @TableField(exist = false)
    private String toAvatar;

    /**
     * 消息类型; 1.文件 2.聊天
     */
    @ApiModelProperty("消息类型; 1.文件 2.聊天")
    @Excel(name = "消息类型; 1.文件 2.聊天")
    private String msgType;

    /**
     * 消息内容
     */
    @ApiModelProperty("消息内容")
    @Excel(name = "消息内容")
    private String content;

    /**
     * ID索引
     */
    @ApiModelProperty("ID索引")
    @Excel(name = "ID索引")
    private String idIndex;

    /**
     * 文件列表
     */
    @ApiModelProperty("文件列表")
    @TableField(exist = false)
    private List<DocInfo> fileList;


    public String getFromAvatar() {
        return fromAvatar;
    }

    public void setFromAvatar(String fromAvatar) {
        this.fromAvatar = fromAvatar;
    }

    public String getToAvatar() {
        return toAvatar;
    }

    public void setToAvatar(String toAvatar) {
        this.toAvatar = toAvatar;
    }

    public String getFromName() {
        return fromName;
    }

    public void setFromName(String fromName) {
        this.fromName = fromName;
    }

    public String getToName() {
        return toName;
    }

    public void setToName(String toName) {
        this.toName = toName;
    }

    public List<DocInfo> getFileList() {
        return fileList;
    }

    public void setFileList(List<DocInfo> fileList) {
        this.fileList = fileList;
    }

    public void setMsgId(Long msgId) {
        this.msgId = msgId;
    }

    public Long getMsgId() {
        return msgId;
    }

    public void setFromId(Long fromId) {
        this.fromId = fromId;
    }

    public Long getFromId() {
        return fromId;
    }

    public void setToId(Long toId) {
        this.toId = toId;
    }

    public Long getToId() {
        return toId;
    }

    public void setMsgType(String msgType) {
        this.msgType = msgType;
    }

    public String getMsgType() {
        return msgType;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getContent() {
        return content;
    }

    public void setIdIndex(String idIndex) {
        this.idIndex = idIndex;
    }

    public String getIdIndex() {
        return idIndex;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("msgId" , getMsgId())
                .append("fromId" , getFromId())
                .append("toId" , getToId())
                .append("msgType" , getMsgType())
                .append("content" , getContent())
                .append("idIndex" , getIdIndex())
                .append("createTime" , getCreateTime())
                .toString();
    }
}
