package com.doc.common.utils;

import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.extractor.WordExtractor;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFParagraph;
import org.springframework.web.multipart.MultipartFile;

import java.io.*;
import java.nio.charset.StandardCharsets;
import java.util.List;

/**
 * 读取文件内容
 * WPS WORD TXT
 *
 * @author wukai
 */
public class FileContentUtils {

    /**
     * 获取正文文件内容，docx方法
     *
     * @param data 二进制文件内容
     * @return
     */
    public static String getContentDocx(byte[] data) {
        // 0表示获取正常，1表示获取异常
        try (InputStream is = new ByteArrayInputStream(data)) {
            //根据需求入参也可以改为文件路径，对应的输入流部分改为new File(路径)即可
            // 2007版本的word
            XWPFDocument xwpf = new XWPFDocument(is);
            // 2007版本，仅支持docx文件处理
            List<XWPFParagraph> paragraphs = xwpf.getParagraphs();
            StringBuilder content = new StringBuilder();

            for (XWPFParagraph paragraph : paragraphs) {
                if (!paragraph.getParagraphText().startsWith("    ")) {
                    content.append(paragraph.getParagraphText().trim()).append("\r\n");
                } else {
                    content.append(paragraph.getParagraphText());
                }
            }
            return content.toString();
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /**
     * 获取正文文件内容，doc方法
     *
     * @param data 二进制文件内容
     * @return
     */
    public static String getContentDoc(byte[] data) {
        try (InputStream is = new ByteArrayInputStream(data)) {
            // 2003版本的word
            WordExtractor wordExtractor = new WordExtractor(is);
            // 2003版本 仅doc格式文件可处理，docx文件不可处理
            String[] text = wordExtractor.getParagraphText();
            StringBuilder content = new StringBuilder();

            // 获取段落，段落缩进无法获取，可以在前添加空格填充
            for (String str : text) {
                if (!str.startsWith("    ")) {
                    content.append(str.trim()).append("\r\n");
                } else {
                    content.append(str);
                }
            }
            return content.toString();
        } catch (IllegalArgumentException e) {
            //做兼容,因为onlyoffice在线编辑时，会将2003的文档保存为word2007的格式。
            return getContentDocx(data);
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /**
     * 获取正文文件内容，wps方法
     *
     * @param data 二进制文件内容
     * @return
     */
    public static String getContentWps(byte[] data) {
        // 0表示获取正常，1表示获取异常
        try (InputStream is = new ByteArrayInputStream(data)) {
            // wps版本word
            HWPFDocument hwpf = new HWPFDocument(is);

            // 文档文本内容
            String[] text = new WordExtractor(hwpf).getParagraphText();
            StringBuilder content = new StringBuilder();
            if (text != null && text.length > 0) {
                for (String str : text) {
                    if (!str.startsWith("    ")) {
                        content.append(str.trim()).append("\r\n");
                    } else {
                        content.append(str);
                    }
                }
            }
            return content.toString();
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    public static String getContentTxt(byte[] data) {
        return new String(data, StandardCharsets.UTF_8).trim();
//        try (InputStream is = new ByteArrayInputStream(data); BufferedReader br = new BufferedReader(data)) {
//            StringBuilder sb = new StringBuilder();
//            String line;
//            while ((line = br.readLine()) != null) {
//                sb.append(line).append(System.lineSeparator());
//            }
//            return sb.toString();
//        } catch (IOException e) {
//            e.printStackTrace();
//            return "";
//        }
    }
}
